RenderObjectData class

Data of a RenderObject and its children, that is used to render the render tree in 3D.

Constructors

RenderObjectData({required String type, required Rect paintBounds})
Creates the data for a RenderObject.
RenderObjectData.capture(RenderObject renderObject)
Captures the RenderObjectData for the given renderObject and its children.
factory
RenderObjectData.fromJson(Map<String, Object?> json)
Deserializes a RenderObjectData and its children from the given json.
factory

Properties

children → List<RenderObjectData>
The data of the RenderObject's children.
no setter
descendants → List<RenderObjectData>
The data of the RenderObject's descendants.
no setter
hashCode → int
The hash code for this object.
no setterinherited
level → int
The level of the RenderObject in the render tree.
no setter
paintBounds → Rect
The paint bounds of the RenderObject in the global coordinate system.
final
parent → RenderObjectData?
The data of the RenderObject's parent.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The runtime type of the RenderObject.
final

Methods

addChild(RenderObjectData child) → void
Adds the given RenderObjectData as a child of this RenderObjectData.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
The JSON representation of this instance.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited